import * as squint_core from 'squint-cljs/core.js';
import { InputRule, wrappingInputRule } from 'prosemirror-inputrules';
import { Selection, TextSelection } from 'prosemirror-state';
import { findWrapping } from 'prosemirror-transform';
import * as pm_transform from 'prosemirror-transform';
import { schema } from './../schema.mjs';
var supported_marks = ({ "`": "monospace", "_": "em", "*": "strong", "~": "strikethrough" });
var mark_input_rule = function (offset, state, match, start, end) {
let mark1 = match[1];
let mark_name2 = squint_core.get(supported_marks, mark1);
let marked_content3 = match[2];
let mark_instance4 = schema.mark(mark_name2);
let mark_type5 = squint_core.get(mark_instance4, "type");
let marked_content_start6 = (start + offset);
return state.tr.setMeta("input-rule", mark_name2).insertText(marked_content3, marked_content_start6, end).addMark(marked_content_start6, (marked_content_start6 + squint_core.count(marked_content3)), mark_instance4).removeStoredMark(mark_type5)
};
var atx_heading_rule = function (state, match, start, end) {
let node_type1 = state.schema.nodes.heading;
let $start2 = state.doc.resolve(start);
let attrs3 = ({ "level": squint_core.count(match[1]) });
let start_index4 = $start2.index(-1);
let start_index_after5 = $start2.indexAfter(-1);
let start_node6 = $start2.node(-1);
if (squint_core.not(start_node6.canReplaceWith(start_index4, start_index_after5, node_type1))) {
return null} else {
return state.tr.setMeta("input-rule", squint_core.get(node_type1, "name")).delete(start, end).setBlockType(start, start, node_type1, attrs3)}
};
var exit_mark_input_handler = function (state, _match) {
let $cursor1 = state.selection.$cursor;
let pos2 = $cursor1.pos;
let temp__23223__auto__3 = squint_core.seq((function () {
 let or__23535__auto__4 = state.storedMarks;
if (squint_core.truth_(or__23535__auto__4)) {
return or__23535__auto__4} else {
return $cursor1.marks()}
})());
if ((temp__23223__auto__3 == null)) {
return null} else {
let marks5 = temp__23223__auto__3;
return squint_core.reduce((function (tr, mark) {
return tr.removeStoredMark(mark)
}), state.tr.insertText(" ", (pos2 - 1), pos2), marks5)}
};
var formula_input_rule = (function () {
 let f19 = (function (var_args) {
let G__221 = arguments.length;
switch (G__221) {case 4:
return f19.cljs$core$IFn$_invoke$arity$4((arguments[0]), (arguments[1]), (arguments[2]), (arguments[3]))
break;
case 5:
return f19.cljs$core$IFn$_invoke$arity$5((arguments[0]), (arguments[1]), (arguments[2]), (arguments[3]), (arguments[4]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f19.cljs$core$IFn$_invoke$arity$4 = (function (state, match, start, end) {
return formula_input_rule(({  }), state, match, start, end)
});
f19.cljs$core$IFn$_invoke$arity$5 = (function (p__23, state, match, start, end) {
let map__34 = p__23;
let inline_QMARK_5 = squint_core.get(map__34, "inline?");
let offset6 = squint_core.get(map__34, "offset", 0);
let node_type7 = (function () {
 let nodes8 = state.schema.nodes;
if (squint_core.truth_(inline_QMARK_5)) {
return nodes8.inline_formula} else {
return nodes8.formula}
})();
return state.tr.setMeta("input-rule", "formula").setSelection(new Selection(state.doc.resolve((start + offset6)), state.doc.resolve(end))).replaceSelectionWith((squint_core.truth_(inline_QMARK_5)) ? (node_type7.createAndFill(({  }), schema.text(squint_core.get(match, 1)))) : (node_type7.createAndFill()))
});
f19.cljs$lang$maxFixedArity = 5;
return f19
})();
var wrapping_input_handler = function (node_type, state, match, start, end) {
let tr1 = state.tr.delete(start, end);
console.log("R", tr1.doc.resolve(start).blockRange());
let temp__23223__auto__2 = tr1.doc.resolve(start).blockRange();
if ((temp__23223__auto__2 == null)) {
return null} else {
let range3 = temp__23223__auto__2;
let temp__23223__auto__4 = findWrapping(range3, node_type);
if ((temp__23223__auto__4 == null)) {
return null} else {
let wrapping5 = temp__23223__auto__4;
return tr1.wrap(range3, wrapping5)}}
};
var build_input_rules = function (schema) {
return [new InputRule(/^(#{1,4})\s$/, atx_heading_rule), wrappingInputRule(/^\s*([-+*])\s$/, schema.nodes.bullet_list), wrappingInputRule(/^\s*(1[\)\.])\s$/, schema.nodes.numbered_list), wrappingInputRule(/^\s*([-+*]\[[x ]*\])\s$/, schema.nodes.todo_list), wrappingInputRule(/^\s*(>+)\s$/, schema.nodes.blockquote), new InputRule(/^(\$\$)\s$/, formula_input_rule), new InputRule(/^\$([^\$]*[^ ])\$$/, squint_core.partial(formula_input_rule, ({ "inline?": true }))), new InputRule(/\s\$([^\$]*[^ ])\$$/, squint_core.partial(formula_input_rule, ({ "inline?": true, "offset": 1 }))), new InputRule(/\s([*_~`])([^`]+)\1$/, squint_core.partial(mark_input_rule, 1)), new InputRule(/^([*_~`])([^`]+)\1$/, squint_core.partial(mark_input_rule, 0)), new InputRule(/\s\s$/, exit_mark_input_handler)]
};
var input_rules = build_input_rules(schema);

export { supported_marks, mark_input_rule, atx_heading_rule, exit_mark_input_handler, formula_input_rule, wrapping_input_handler, build_input_rules, input_rules }
